@@ -9,6 +9,6 @@ else:
 def test_entrypoint_registered():
     discovered_plugins = entry_points(group="flake8.report")
     matching_plugins = [
-        plugin for plugin in discovered_plugins if plugin.name == "github-annotations"
+        plugin for plugin in discovered_plugins if plugin.name == "github"
     ]
     assert len(matching_plugins) == 1
